@@ -1,4 +1,4 @@
-// Copyright © 2015-2017 Hilko Bengen <bengen@hilluzination.de>
+// Copyright © 2015-2019 Hilko Bengen <bengen@hilluzination.de>
 // All rights reserved.
 //
 // Use of this source code is governed by the license that can be
@@ -118,10 +118,16 @@ func (r *Rule) Tags() (tags []string) {
 	return
 }
 
-// Metas returns a map containing the rule's meta variables. Values
-// can be of type string, int, bool, or nil.
-func (r *Rule) Metas() (metas map[string]interface{}) {
-	metas = make(map[string]interface{})
+// Meta represents a rule meta variable. Value can be of type string,
+// int, boolean, or nil.
+type Meta struct {
+	Identifier string
+	Value      interface{}
+}
+
+// MetaList returns the rule's meta variables as a list of Meta
+// objects. It does not share the limitation of Metas().
+func (r *Rule) MetaList() (metas []Meta) {
 	var size C.int
 	C.rule_metas(r.cptr, nil, &size)
 	if size == 0 {
@@ -129,23 +135,64 @@ func (r *Rule) Metas() (metas map[string]interface{}) {
 	}
 	mptrs := make([]*C.YR_META, int(size))
 	C.rule_metas(r.cptr, &mptrs[0], &size)
-	for _, m := range mptrs {
-		var id, str *C.char
-		C.meta_get(m, &id, &str)
-		switch m._type {
+	for _, cptr := range mptrs {
+		var cid, cstr *C.char
+		C.meta_get(cptr, &cid, &cstr)
+		id := C.GoString(cid)
+		var val interface{}
+		switch cptr._type {
 		case C.META_TYPE_NULL:
-			metas[C.GoString(id)] = nil
+			val = nil
 		case C.META_TYPE_STRING:
-			metas[C.GoString(id)] = C.GoString(str)
+			val = C.GoString(cstr)
 		case C.META_TYPE_INTEGER:
-			metas[C.GoString(id)] = int(m.integer)
+			val = int(cptr.integer)
 		case C.META_TYPE_BOOLEAN:
-			metas[C.GoString(id)] = m.integer != 0
+			val = (cptr.integer != 0)
 		}
+		metas = append(metas, Meta{id, val})
 	}
 	return
 }
 
+// MetaMap returns a map containing the rule's meta variables, with
+// the variable names as keys. Values are collected into lists, this
+// allows for multiple variables with the same; individual values can
+// be of type string, int, bool, or nil.
+func (r *Rule) MetaMap() (metas map[string][]interface{}) {
+	metas = make(map[string][]interface{})
+	for _, m := range r.MetaList() {
+		metas[m.Identifier] = append(metas[m.Identifier], m.Value)
+	}
+	return
+}
+
+// Metas returns a map containing the rule's meta variables, with the
+// variable names as keys. Values can be of type string, int, bool, or
+// nil.
+//
+// Deprecated: If there are multiple meta variables with the same
+// name, the returned map contains only the last variable.
+//
+// Use MetaList or MetaMap instead.
+func (r *Rule) Metas() (metas map[string]interface{}) {
+	metas = make(map[string]interface{})
+	for _, m := range r.MetaList() {
+		metas[m.Identifier] = m.Value
+	}
+	return
+}
+
+// IsPrivate returns true if the rule is marked as private
+func (r *Rule) IsPrivate() bool {
+	return (r.cptr.g_flags & C.RULE_GFLAGS_PRIVATE) != 0
+}
+
+// IsGlobal returns true if the rule is marked as global
+func (r *Rule) IsGlobal() bool {
+	return (r.cptr.g_flags & C.RULE_GFLAGS_GLOBAL) != 0
+}
+
 // String represents a string as part of a rule
 type String struct{ cptr *C.YR_STRING }
 
